---
title: <span class="badge builder"></span> Row
---
# <span class="badge builder"></span> Row

## Constructor

```python
Row(title: str)
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.RowPanel
```

### <span class="badge object-method"></span> collapsed

Whether this row should be collapsed or not.

Note: panels added directly to a row will be stripped by Grafana unless the row is collapsed

```python
def collapsed(collapsed: bool) -> typing.Self
```

### <span class="badge object-method"></span> datasource

Name of default datasource for the row

```python
def datasource(datasource: dashboard.DataSourceRef) -> typing.Self
```

### <span class="badge object-method"></span> grid_pos

Row grid position

```python
def grid_pos(grid_pos: dashboard.GridPos) -> typing.Self
```

### <span class="badge object-method"></span> id_val

Unique identifier of the panel. Generated by Grafana when creating a new panel. It must be unique within a dashboard, but not globally.

```python
def id_val(id_val: int) -> typing.Self
```

### <span class="badge object-method"></span> repeat

Name of template variable to repeat for.

```python
def repeat(repeat: str) -> typing.Self
```

### <span class="badge object-method"></span> title

Row title

```python
def title(title: str) -> typing.Self
```

### <span class="badge object-method"></span> with_panel

List of panels in the row

Note: since panels added directly to a row will be stripped by Grafana unless the row is collapsed,

this option will set the current row as collapsed.

```python
def with_panel(panel: cogbuilder.Builder[dashboard.Panel]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [RowPanel](./object-RowPanel.md)
